/*
 * @(#)E.java	1.0 98/07/07
 * 
 * Copyright (c) 1998 Studio Associato I-Tech All Rights Reserved.
 * 
 * 
 * I-Tech MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. I-Tech SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 * 
 * CopyrightVersion 1.0
 * 
 */

package com.studioitech.gulli.MJDBC;

import java.io.*;

/**
 * <P> A class to handle debug message. It store messages until flush()
 *  is done, or autoflush() is called.
 *
 *  It is useful for servlet enviroment. During the init() phase, one 
 *  can not produce HTML output directly. So you can use E class in this way
 *
 * <PRE>
 *
 *	public void init(ServletConfig config)
 *		throws ServletException
 *	{
 *		super.init(config);     
 *      doYourInitWork();	
 *		E.debug("Initing done", 0);
 *	}
 *
 *  <p>
 *
 *  // doGet Method - method that runs when the servlet is hit via GET
 *  <p>
 *    public void doGet(HttpServletRequest req, HttpServletResponse res)
 *		throws ServletException, IOException
 *
 *    {
 *
 *		PrintWriter	out;
 *		res.setContentType("text/html");
 *		out = res.getWriter ();
 *
 *		E.setOutput(out);    // set output channel
 *		E.flush();           // flush the acquired buffer, if any
 *		E.setAutoFlush(true);// now set autoflush
 *
 *      doYourDoGetCode();
 *     }
 * </PRE> 
 */

public class E 
{

	static PrintWriter out = null;
	static int DEBUG_LEVEL = 0;
	static StringBuffer msg = new StringBuffer();
	static boolean autoflush = false;

	/**
	 * 
	 * set DEBUG_LEVEL to the given integer value <p>
	 *
	 * @param dl the debug level to set
	 *
	 */
	public static void setDebugLevel(int dl)
	{
		DEBUG_LEVEL = dl;
	}


	/**
	 * 
	 * set the PrintWriter to write message <p>
	 *
	 * @param pw the PrintWriter channel to set
	 *
	 */
	public static void setOutput(PrintWriter pw)
	{
		out = pw;
	}

	/**
	 * 
	 * set autoflush to the given boolean value<p>
	 *
	 * @param value the boolean value to set
	 *
	 */
	public static void setAutoFlush(boolean value)
	{
		autoflush = value;
	}

	/**
	 * 
	 * Print a debug message if its associated level is less
	 * then current DEBUG_LEVEL.<p> Note that:
	 *
	 * <ul>
	 *   <li> If autoflush is not true the message is buffered
	 *   <li> If autoflush is true but the PrintWriter channel 
	 *        is not setted via setOutput(), the message is discarded
	 * </ul>
	 *
	 * @param s the string to print
	 * @param level the debug level to set
	 *
	 */
	public static void debug(String s, int level)
	{

		// Control debug level 
		if (level<= DEBUG_LEVEL){
			
			// Append to the msg
			if (!autoflush){

				msg.append(s + "<br>");

			}else{

				if (out != null){

					out.println(s + "<br>");
					out.flush();
				}
			}
		}
	}

	/**
	 * 
	 * Print the buffer if the associated PrintWriter channel is
	 * setted via setOutput(); In every case it frees the buffer <p>
	 *
	 */
	public static void flush(){

		if (out != null){

			out.println(new String(msg) + "<br>");
			out.flush();
		}

		msg = new StringBuffer();
	}

}

