/*
 * @(#)dbConnection.java	1.0 98/07/07
 * 
 * Copyright (c) 1998 Studio Associato I-Tech All Rights Reserved.
 * 
 * 
 * I-Tech MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF THE
 * SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, OR NON-INFRINGEMENT. I-Tech SHALL NOT BE LIABLE FOR ANY DAMAGES
 * SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING OR DISTRIBUTING
 * THIS SOFTWARE OR ITS DERIVATIVES.
 * 
 * CopyrightVersion 1.0
 * 
 */
package com.studioitech.gulli.MJDBC;


import java.util.*;
import java.sql.*;

/**
 * <P>A dbConnection represents a Connection and a Statement 
 * in JDBC terminology.
 *
 * <P> Besides a dbConnection has all inner characteristic to be 
 * handled in a multi-thread safe manner
 *
 */

public class dbConnection 
{

	/**
	 * access JDBC connection in the chosen dbConnection.<p>
	 */

	public Connection db;     // A connection to Database
	
	/**
	 * access JDBC statement in the chosen dbConnection.<p>
	 */

	public Statement st;      // A statement   
	private boolean isBusy; // control the status of connection

	/**
	 * Constructor of the dbConnection: A dbConnection is defined
	 * as a triple (Connection, Statement, busyState)<p>
	 * 
	 * @param url  the url to connect database (e.g.: jdbc:postgresql:database )
	 * @param usr  the name of database's user (e.g.: test)
	 * @param pwd  the password database user  (e.g.: test)
     *
	 * @exception SQLException if a database-access error occurs.
	 *
	 */


	public dbConnection(String url, String usr, String pwd)
		throws SQLException
	{

		
		E.debug("Connecting DB " + url + " " + usr + " " + pwd, 0);

		try {
			db = DriverManager.getConnection(url, usr, pwd);
		
		} catch (SQLException sqle){
			
			E.debug("Problems initing connection " + sqle.toString(), 0);
			throw sqle;
		}
		
		try {
			st = db.createStatement();

		} catch (SQLException sqle1){

			E.debug("Problems initing statement " + sqle1.toString(), 0);
			throw sqle1;
		}

		isBusy = false;  // this connection is not busy

		E.debug("A connection is created", 2);
	}

	
	/**
	 * Close a connection and its associated statement<br> <b>Note:</b> this  
	 * MUST be executed in a Multi-Thread safe enviroment
	 * 
	 * @exception SQLException if a database-access error occurs.
	 *
	 */

	public void closeConnection()
		throws SQLException
	{
	
		st.close();
		db.close();

		E.debug("A connection is closed", 2);
	}


	/**
	 * Take a non yet used connection, It is multithread safe 
	 *
	 * @return true if the selected connection is available
	 */

	public synchronized boolean takeConnection(){

		if(isBusy == true)      // busy
			return false;       // we cannot take it
		else
		{
			isBusy = true;      // make is busy
			return true;        // we take it
		}
	}

	/**
	 * Set this connection as available, It is multithread safe 
	 *
	 */

	public synchronized void freeConnection(){

		isBusy = false;
		E.debug("NOW, A connection is free", 2);
	}
}


